@@ -97,7 +97,7 @@ fn impl_checkout_server(ast: &syn::DeriveInput) -> TokenStream {
                         request_body_max_bytes: 2048 * 1024,
                     },
                     api,
-                    *checkout_server::Arc::new(ServerContext {
+                    *checkout_server::Arc::new(checkout_server::ServerContext {
                         context_provider: self
                     }),
                     &log,
